%define major   1
%define libname %mklibname fdt %{major}
%define devname %mklibname fdt -d

%global with_mingw 0

%if 0%{?mageia}
%global with_mingw 1
%endif

Name:          dtc
Version:       1.7.2
Release:       %mkrel 1
Summary:       Device Tree Compiler
Group:         Development/Tools
License:       GPLv2+
URL:           https://devicetree.org/

Source0:       https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.xz

BuildRequires: meson
BuildRequires: gcc make
BuildRequires: flex bison swig
BuildRequires: pkgconfig(yaml-0.1)
BuildRequires: pkgconfig(valgrind)
BuildRequires: python3-devel
BuildRequires: python3-pip
BuildRequires: python3-setuptools
BuildRequires: python3-setuptools_scm
BuildRequires: python3-wheel

%if %{with_mingw}
BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
%endif

%description
Devicetree is a data structure for describing hardware. Rather than hard coding
every detail of a device into an operating system, many aspects of the hardware
can be described in a data structure that is passed to the operating system at
boot time. The devicetree is used by OpenFirmware, OpenPOWER Abstraction Layer
(OPAL), Power Architecture Platform Requirements (PAPR) and in the standalone
Flattened Device Tree (FDT) form.

%package -n %{libname}
Summary: Device tree library
Group: System/Libraries

%description -n %{libname}
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n %{devname}
Summary: Development headers for device tree library
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: libfdt-devel = %{version}-%{release}

%description -n %{devname}
This package provides development files for libfdt

%package -n python3-libfdt
Summary: Python 3 bindings for device tree library
%{?python_provide:%python_provide python3-libfdt}
Requires: %{name} = %{version}-%{release}

%description -n python3-libfdt
This package provides python3 bindings for libfdt

%if %{with_mingw}
%package -n mingw32-libfdt
Summary: MinGW Device tree library
BuildArch: noarch

%description -n mingw32-libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n mingw32-libfdt-static
Summary: Static version of MinGW Device tree library
Requires: mingw32-libfdt = %{version}-%{release}
BuildArch: noarch

%description -n mingw32-libfdt-static
This package provides the static library of mingw32-libfdt

%package -n mingw64-libfdt
Summary: MinGW Device tree library
BuildArch: noarch

%description -n mingw64-libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n mingw64-libfdt-static
Summary: Static version of MinGW Device tree library
Requires: mingw64-libfdt = %{version}-%{release}
BuildArch: noarch

%description -n mingw64-libfdt-static
This package provides the static library of mingw64-libfdt

%{?mingw_debug_package}
%endif

%prep
%autosetup -p1
# to prevent setuptools from installing an .egg, we need to pass --root to setup.py install
# since $(PREFIX) already contains %%{buildroot}, we set root to /
# .eggs are going to be deprecated, see https://github.com/pypa/pip/issues/11501
sed -i 's@--prefix=$(PREFIX)@--prefix=$(PREFIX) --root=/@' pylibfdt/Makefile.pylibfdt


%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%meson
%meson_build

%if %{with_mingw}
%mingw_meson -Dtests=false -Dtools=false
%mingw_ninja
%endif

%install
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%meson_install

find %{buildroot} -type f -name "*.a" -delete

# we don't want ftdump and it conflicts with freetype-demos, so drop it (rhbz 797805)
rm -f %{buildroot}%{_bindir}/ftdump

%if %{with_mingw}
%mingw_ninja_install
%mingw_debug_install_post
%endif

%files
%license GPL
%doc Documentation/manual.txt
%{_bindir}/*

%files -n %{libname}
%license GPL
%{_libdir}/libfdt.so.%{version}
%{_libdir}/libfdt.so.%{major}

%files -n %{devname}
%{_libdir}/libfdt.so
%{_libdir}/pkgconfig/libfdt.pc
%{_includedir}/*

%files -n python3-libfdt
%{python3_sitearch}/libfdt-%{version}-py%{python3_version}.egg-info/
%{python3_sitearch}/_libfdt%{python3_ext_suffix}
%pycached %{python3_sitearch}/libfdt.py

%if %{with_mingw}
%files -n mingw32-libfdt
%license GPL
%{mingw32_bindir}/libfdt-1.dll
%{mingw32_includedir}/*fdt*.h
%{mingw32_libdir}/libfdt.dll.a
%{mingw32_libdir}/pkgconfig/libfdt.pc

%files -n mingw32-libfdt-static
%{mingw32_libdir}/libfdt.a

%files -n mingw64-libfdt
%license GPL
%{mingw64_bindir}/libfdt-1.dll
%{mingw64_includedir}/*fdt*.h
%{mingw64_libdir}/libfdt.dll.a
%{mingw64_libdir}/pkgconfig/libfdt.pc

%files -n mingw64-libfdt-static
%{mingw64_libdir}/libfdt.a
%endif



%changelog
* Tue Dec 24 2024 wally <wally> 1.7.2-1.mga10
+ Revision: 2129811
- new version 1.7.2

* Mon Jan 01 2024 daviddavid <daviddavid> 1.7.0-7.mga10
+ Revision: 2025006
- rebuild for py3.12

* Tue Dec 05 2023 tv <tv> 1.7.0-6.mga10
+ Revision: 2013521
- Don't install a Python .egg

* Sat Sep 16 2023 tv <tv> 1.7.0-5.mga10
+ Revision: 1987092
- Update to 1.7.0

* Sun Nov 06 2022 tv <tv> 1.6.1-5.mga9
+ Revision: 1904023
- Add mingw sub-packages

* Sat Mar 26 2022 umeabot <umeabot> 1.6.1-4.mga9
+ Revision: 1827819
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 1.6.1-3.mga9
+ Revision: 1782759
- Rebuild for python-3.10

* Sat Oct 23 2021 tv <tv> 1.6.1-2.mga9
+ Revision: 1752749
- Update to 1.6.1

* Sat Mar 27 2021 tv <tv> 1.5.1-4.mga9
+ Revision: 1710861
- rebuild for python 3.9

* Sun Jul 05 2020 joequant <joequant> 1.5.1-3.mga8
+ Revision: 1602131
- bump
- build gcc10

* Sun Feb 16 2020 umeabot <umeabot> 1.5.1-2.mga8
+ Revision: 1532213
- Mageia 8 Mass Rebuild

* Mon Sep 16 2019 tv <tv> 1.5.1-1.mga8
+ Revision: 1442248
- new release
- use our build flags during build
- switch for python3 for building

* Sun Sep 23 2018 umeabot <umeabot> 1.4.6-2.mga7
+ Revision: 1297520
- Mageia 7 Mass Rebuild

* Fri Jun 01 2018 wally <wally> 1.4.6-1.mga7
+ Revision: 1233500
- new version 1.4.6
- sync patches with fedora

* Fri Apr 15 2016 tv <tv> 1.4.1-1.mga6
+ Revision: 1001701
- imported package dtc


* Fri Apr 15 2016 Thierry Vignaud <tv@mageia.org> 1.4.1-1.mga6
- import from FC

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jun 16 2015 Peter Robinson <pbrobinson@fedoraproject.org> 1.4.1-4
- Use %%license

* Sat Feb 21 2015 Till Maas <opensource@till.name> - 1.4.1-3
- Rebuilt for Fedora 23 Change
  https://fedoraproject.org/wiki/Changes/Harden_all_packages_with_position-independent_code

* Mon Jan  5 2015 Peter Robinson <pbrobinson@fedoraproject.org> 1.4.1-2
- Use tar file from kernel.org

* Mon Jan  5 2015 Peter Robinson <pbrobinson@fedoraproject.org> 1.4.1-1
- New dtc 1.4.1 release
- Update URL and Sources
- Cleanup spec

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Dec 21 2013 Ville Skyttä <ville.skytta@iki.fi> - 1.4.0-3
- Avoid shell invocation and fix deps of libfdt %%post* scripts.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Jun 24 2013 Josh Boyer <jwboyer@redhat.com> - 1.4.0-1
- New dtc 1.4.0 release (rhbz 977480)

* Thu Jun 06 2013 Josh Boyer <jwboyer@redhat.com> - 1.3.0-8
- Fix type specifier error (from Dan Horák)

* Mon Jun 03 2013 Josh Boyer <jwboyer@redhat.com> - 1.3.0-7
- Update dtc to include libfdt_env.h (rhbz 969955)

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Feb 27 2012 Josh Boyer <jwboyer@redhat.com>
- Don't package ftdump (rhbz 797805)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Jun 28 2011 Josh Boyer <jwboyer@gmail.com>
- Fixup error during tarball upload

* Tue Jun 28 2011 Josh Boyer <jwboyer@gmail.com>
- Point to git tree for URL (#717217)
- Add libfdt subpackages based on patch from Paolo Bonzini (#443882)
- Update to latest release

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Aug 28 2008 Josh Boyer <jwboyer@gmail.com>
- Update to latest release

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.1.0-2
- Autorebuild for GCC 4.3

* Thu Jan 24 2008 Josh Boyer <jwboyer@gmail.com>
- Update to 1.1.0

* Tue Aug 21 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Bump and rebuild

* Thu Aug 09 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Update to official 1.0.0 release

* Fri Aug 03 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Update license field

* Mon Jul 09 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Update to new snapshot

* Tue Jul 03 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Update to new snapshot
- Drop upstreamed install patch

* Fri Jun 29 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Fix packaging errors

* Thu Jun 28 2007 Josh Boyer <jwboyer@jdub.homelinux.org>
- Initial packaging
